@@ -126,8 +126,8 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
      es_data <- data.frame(r = r, n = n, stringsAsFactors = FALSE)
      es_data$n_adj <- n_adj
      if(is.null(sample_id)) sample_id <- paste0("Sample #", 1:nrow(es_data))
-     if(!is.null(citekey)) es_data <- cbind(citekey = citekey, es_data)
-     es_data <- cbind(sample_id = sample_id, es_data)
+     if(!is.null(citekey)) es_data <- cbind(citekey = citekey, es_data) %>% mutate(citekey = as.character(citekey))
+     es_data <- cbind(sample_id = sample_id, es_data) %>% mutate(sample_id = as.character(sample_id))
 
      out <- ma_wrapper(es_data = es_data, es_type = "r", ma_type = "bb", ma_fun = .ma_r_bb,
                        moderator_matrix = moderators, moderator_type = moderator_type, cat_moderators = cat_moderators,
@@ -239,8 +239,8 @@ ma_r_bb <- ma_r_barebones <- function(r, n, n_adj = NULL, sample_id = NULL, cite
                                    residual = r - mean_r_xy, stringsAsFactors = FALSE)
           if("pi" %in% colnames(data)) escalc_obj$pi <- data$pi
           if("pa" %in% colnames(data)) escalc_obj$pa <- data$pa
-          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj)
-          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj)
+          if(!is.null(citekey)) escalc_obj <- cbind(citekey = citekey, escalc_obj) %>% mutate(citekey = as.character(citekey))
+          if(!is.null(sample_id)) escalc_obj <- cbind(sample_id = sample_id, escalc_obj) %>% mutate(sample_id = as.character(sample_id))
           if(any(colnames(data) == "original_order")) escalc_obj <- cbind(original_order = data$original_order, escalc_obj)
           class(escalc_obj) <- c("escalc", "data.frame")
      }
