@@ -1,28 +1,21 @@
 #### filter ####
-#' @export
-#' @keywords internal
-#' @importFrom dplyr filter
-#' @method filter ma_table
 filter.ma_table <- function(.data, ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method filter_all ma_table
 filter_all.ma_table <- function(.tbl, vars_predicate){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method filter_at ma_table
 filter_at.ma_table <- function(.tbl, .vars, .vars_predicate){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method filter_if ma_table
 filter_if.ma_table <- function(.tbl, predicate, .vars_predicate){
      reattribute(.tbl, NextMethod())
@@ -31,29 +24,23 @@ filter_if.ma_table <- function(.tbl, predicate, .vars_predicate){
 
 
 #### select ####
-#' @export
-#' @keywords internal
-#' @method select ma_table
 select.ma_table <- function(.data, ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method select_all ma_table
 select_all.ma_table <- function(.tbl, .funs = list(), ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method select_at ma_table
 select_at.ma_table <- function(.tbl, .vars, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method select_if ma_table
 select_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
@@ -62,29 +49,23 @@ select_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
 
 
 #### rename ####
-#' @export
-#' @keywords internal
-#' @method rename ma_table
 rename.ma_table <- function(.data, ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method rename_all ma_table
 rename_all.ma_table <- function(.tbl, .funs = list(), ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method rename_at ma_table
 rename_at.ma_table <- function(.tbl, .vars, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method rename_if ma_table
 rename_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
@@ -93,29 +74,23 @@ rename_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
 
 
 #### arrange ####
-#' @export
-#' @keywords internal
-#' @method arrange ma_table
 arrange.ma_table <- function(.data, ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method arrange_all ma_table
 arrange_all.ma_table <- function(.tbl, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method arrange_at ma_table
 arrange_at.ma_table <- function(.tbl, .vars, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method arrange_if ma_table
 arrange_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
@@ -125,7 +100,6 @@ arrange_if.ma_table <- function(.tbl, .predicate, .funs = list(), ...){
 
 #### grouping ####
 #' @export
-#' @keywords internal
 #' @method ungroup ma_table
 ungroup.ma_table <- function (x, ...){
      x <- reattribute(x, NextMethod())
@@ -137,28 +111,24 @@ ungroup.ma_table <- function (x, ...){
 }
 
 #' @export
-#' @keywords internal
 #' @method group_by ma_table
 group_by.ma_table <- function (.data, ..., add = FALSE){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method group_by_all ma_table
 group_by_all.ma_table <- function(.tbl, .funs = list(), ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method group_by_at ma_table
 group_by_at.ma_table <- function(.tbl, .vars, .funs = list(), ..., .add = FALSE){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method group_by_if ma_table
 group_by_if.ma_table <- function(.tbl, .predicate, .funs = list(), ..., .add = FALSE){
      reattribute(.tbl, NextMethod())
@@ -167,29 +137,23 @@ group_by_if.ma_table <- function(.tbl, .predicate, .funs = list(), ..., .add = F
 
 
 #### mutate ####
-#' @export
-#' @keywords internal
-#' @method mutate ma_table
 mutate.ma_table <- function(.data, ...){
      reattribute(.data, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method mutate_all ma_table
 mutate_all.ma_table <- function(.tbl, .funs, ...){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method mutate_at ma_table
 mutate_at.ma_table <- function(.tbl, .vars, .funs, ..., .cols = NULL){
      reattribute(.tbl, NextMethod())
 }
 
 #' @export
-#' @keywords internal
 #' @method mutate_if ma_table
 mutate_if.ma_table <- function(.tbl, .predicate, .funs, ...){
      reattribute(.tbl, NextMethod())
@@ -199,28 +163,24 @@ mutate_if.ma_table <- function(.tbl, .predicate, .funs, ...){
 
 #### transmute ####
 #' @export
-#' @keywords internal
 #' @method transmute ma_table
 transmute.ma_table <- function(.data, ...){
      NextMethod()
 }
 
 #' @export
-#' @keywords internal
 #' @method transmute_all ma_table
 transmute_all.ma_table <- function(.tbl, .funs, ...){
      NextMethod()
 }
 
 #' @export
-#' @keywords internal
 #' @method transmute_at ma_table
 transmute_at.ma_table <- function(.tbl, .vars, .funs, ..., .cols = NULL){
      NextMethod()
 }
 
 #' @export
-#' @keywords internal
 #' @method transmute_if ma_table
 transmute_if.ma_table <- function(.tbl, .predicate, .funs, ...){
      NextMethod()
@@ -230,15 +190,11 @@ transmute_if.ma_table <- function(.tbl, .predicate, .funs, ...){
 
 #### subset ####
 #' @export
-#' @keywords internal
-#' @method subset ma_table
 subset.ma_table <- function (x, subset, select, drop = FALSE, ...){
-     reattribute(x, NextMethod())
+     x <- reattribute(x, subset(as.data.frame(x, stringsAsFactors = FALSE), subset, select, drop, ...))
 }
 
 #' @export
-#' @keywords internal
-#' @method [ ma_table
 `[.ma_table` <- function(x, i = rep(TRUE, nrow(x)), j = rep(TRUE, ncol(x)), drop = if (missing(i)) TRUE else ncol(x) == 1){
      reattribute(x, NextMethod())
-} 
+}
